package App::perlutils; 
use strict;

our $VERSION = '0.024';


1;




__END__

=pod

=head1 NAME

App::perlutils - utils for perl development

=head1 DESCRIPTION

A few useful utilities for perl developers.

=head1 SCRIPTS

=head2 depends

list dependencies for perl modules or scripts, with core info.

=head2 findinc

list all files in @INC. With LS_COLORS!

=head2 func

list all functions defined in **/*.p[lm]

=head2 methods

TODO

=head2 version

get VERSION info from a perl module

=head2 version_up

bump $VERSION.

=head1 REPORTING BUGS

Report bugs and/or feature requests on rt.cpan.org, the repository issue tracker
or directly to L<m@japh.se>

=head1 AUTHOR

  Magnus Woldrich
  CPAN ID: WOLDRICH
  m@japh.se
  L<~/|http://japh.se>
  L<git|http://github.com/trapd00r>

=head1 CONTRIBUTORS

None required yet.

=head1 COPYRIGHT

Copyright 2019- B<THIS MODULE>s L</AUTHOR> and L</CONTRIBUTORS> as listed above.

=head1 LICENSE

This library is free software; you may redistribute it and/or modify it under
the same terms as Perl itself.

=head1 SEE ALSO

L<~/|http://japh.se>

=cut

